"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.LANGS = void 0;
exports.disposeHighlighter = disposeHighlighter;
exports.getHighlighter = getHighlighter;
exports.getSafeLanguage = getSafeLanguage;
exports.isValidLanguage = isValidLanguage;
var _core = require("@shikijs/core");
var _engineJavascript = require("@shikijs/engine-javascript");
var _css = _interopRequireDefault(require("shiki/dist/langs/css.mjs"));
var _html = _interopRequireDefault(require("shiki/dist/langs/html.mjs"));
var _javascript = _interopRequireDefault(require("shiki/dist/langs/javascript.mjs"));
var _json = _interopRequireDefault(require("shiki/dist/langs/json.mjs"));
var _markdown = _interopRequireDefault(require("shiki/dist/langs/markdown.mjs"));
var _php = _interopRequireDefault(require("shiki/dist/langs/php.mjs"));
var _tsx = _interopRequireDefault(require("shiki/dist/langs/tsx.mjs"));
var _typescript = _interopRequireDefault(require("shiki/dist/langs/typescript.mjs"));
var _githubDark = _interopRequireDefault(require("shiki/dist/themes/github-dark.mjs"));
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
/* eslint-disable no-console */

const DEBUG = true;
function log(message, ...args) {
  if (DEBUG) {
    console.log(`[ShikiContext] ${message}`, ...args);
  }
}
const LANGS = exports.LANGS = {
  typescript: _typescript.default,
  javascript: _javascript.default,
  json: _json.default,
  html: _html.default,
  css: _css.default,
  markdown: _markdown.default,
  tsx: _tsx.default,
  php: _php.default,
  plaintext: {
    id: 'plaintext',
    scopeName: 'source.plaintext',
    grammar: {
      patterns: [{
        match: '.*',
        name: 'text.plain'
      }]
    }
  }
};
let highlighterInstance = null;
async function getHighlighter() {
  if (highlighterInstance) {
    log('Returning cached highlighter instance');
    log('Cached highlighter state:', {
      loadedLanguages: highlighterInstance.getLoadedLanguages()
    });
    return highlighterInstance;
  }
  try {
    log('Creating new highlighter instance...');

    // Log language definitions before loading
    log('Language definitions to load:');
    Object.entries(LANGS).forEach(([key, lang]) => {
      log(`Language ${key}:`, {
        id: lang.id,
        scopeName: lang.scopeName,
        hasGrammar: Boolean(lang.grammar),
        embeddedLangs: lang.embeddedLanguages || 'none'
      });
    });

    // Initialize the JavaScript regex engine
    log('Initializing JavaScript regex engine...');
    const engine = (0, _engineJavascript.createJavaScriptRegexEngine)();
    log('Engine created with capabilities:', Object.keys(engine));

    // Prepare languages for loading
    log('Loading language definitions...');
    const languageDefinitions = Object.values(LANGS);
    log(`Prepared ${languageDefinitions.length} language definitions`);

    // Create the highlighter core with static language definitions
    log('Creating highlighter core with config:', {
      languageCount: languageDefinitions.length,
      engineType: typeof engine,
      themeIncluded: Boolean(_githubDark.default)
    });
    highlighterInstance = await (0, _core.createHighlighterCore)({
      langs: languageDefinitions,
      themes: [_githubDark.default],
      engine
    });
    log('Highlighter core created successfully');
    log('Loaded languages:', highlighterInstance.getLoadedLanguages());

    // Verify each language was loaded
    const loadedLangs = highlighterInstance.getLoadedLanguages();
    const missingLangs = Object.keys(LANGS).filter(lang => !loadedLangs.includes(lang));
    if (missingLangs.length) {
      log('WARNING: Some languages failed to load:', missingLangs);
    }
    return highlighterInstance;
  } catch (error) {
    log('Error creating highlighter:', error);
    if (error instanceof Error) {
      log('Error stack:', error.stack);
    }
    throw new Error(`Failed to initialize syntax highlighter: ${error instanceof Error ? error.message : 'Unknown error'}`);
  }
}

// Clean up function
function disposeHighlighter() {
  if (highlighterInstance) {
    log('Disposing highlighter instance');
    highlighterInstance.dispose();
    highlighterInstance = null;
  }
}

// Helper function to validate language
function isValidLanguage(lang) {
  return lang in LANGS;
}

// Helper function to get safe language
function getSafeLanguage(lang) {
  return isValidLanguage(lang) ? lang : 'plaintext';
}
//# sourceMappingURL=SyntaxContext.js.map